( cd usr/lib ; rm -rf libkchlstfilterplugininterfaces.so )
( cd usr/lib ; ln -sf libkchlstfilterplugininterfaces.so.0.0.0 libkchlstfilterplugininterfaces.so )
( cd usr/lib ; rm -rf libkchlstfilterplugininterfaces.so.0 )
( cd usr/lib ; ln -sf libkchlstfilterplugininterfaces.so.0.0.0 libkchlstfilterplugininterfaces.so.0 )
( cd usr/share/doc/HTML/en/kalva ; rm -rf common )
( cd usr/share/doc/HTML/en/kalva ; ln -sf /usr/share/doc/HTML/en/common common )
