<!DOCTYPE kpartgui>
<kpartgui name="kchannellistfilterplugin" version="1">
<MenuBar>
   <Menu name = "file" >
      <Menu name = "channellist" >
         <Menu name="import"><text>Import</text>
            <Action name="import_tv_stations" />
            <Action name="import_tv_stations_from_file" />
         </Menu>
         <Menu name="export"><text>Export</text>
            <Action name="export_tv_stations" />
         </Menu>
      </Menu>
   </Menu>
</MenuBar>
</kpartgui>