<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name = "kalva" version = "1">
<MenuBar>
   <Menu name="file">
      <Menu name = "channellist" ><Text>Channellist</Text>
         <Action name = "save_channellist" />
         <Seperator/>
         <Merge/>
      </Menu>
   </Menu>
   <Menu name="settings">
      <Action name = "toggleSystemTray" />
      <Action name = "dockOnClose" />
   </Menu>
</MenuBar>
</kpartgui>
