<!DOCTYPE kpartgui>
<kpartgui name="kchannellistfilterplugin" version="1">
<MenuBar>
   <Menu name = "file" >
      <Menu name = "channellist" >
         <Action name="scantv" />
      </Menu>
   </Menu>
</MenuBar>
</kpartgui>